class GeneratedOff {
  @lombok.Getter int x;
  GeneratedOff() {
    super();
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated int getX() {
    return this.x;
  }
}
